interesante enlace click aqui

Sin lugar a dudas, aun para las personas que se incian en linux les es dificil enfrentarse a un ordenador que ya tiene winXXX u otro OS, para particionar sin lugar a dudas partition magic es tu amigo recontra amigo, y recomiendo lo usen si lo compran :) , bueno pero en tal caso sino he visto con agrado el live-cd de GPARTED buenazo el live-cd, y bueno encontre este tutorial bien descrito y listito para usar :)
con videos y todo mas facil aqui lo dicho.
IptablesTips
-Capturar todas las peticiones que se hagan a la IP_1 y reenviarlas a IP_2
iptables -t nat -A PREROUTING -d IP_1 -j DNAT --to-destination IP_2
-Capturar todas las peticiones que se hagan al puerto X de la IP_1 y reenviarlas al puerto Y de la IP_2
iptables -t nat -A PREROUTING -p tcp -d IP_1 --dport X -j DNAT --to-destination IP_2:Y
-Bloquear totalmente los paquetes que vengan desde IP
iptables -A INPUT -s IP -j [REJECT ] [DROP]
-Bloquear totalmente los paquetes que tengan como destino IP
iptables -A INPUT -d IP -j [REJECT ] [DROP]
-Bloquear acceso a WinMX
iptables -A FORWARD -d 64.124.41.0/24 -j [REJECT] [DROP]
-Bloquear acceso a eDonkey
iptables -A FORWARD -p tcp --dport 4661:4662 -j [REJECT] [DROP]
iptables -A FORWARD -p udp --dport 4665 -j [REJECT] [DROP]
aqui fuente
pd.- añadir mas :)
recontra utilisimo, lo vi en fedora me parece, pero ahora ya esta en debian 4.0, un apt-get install tomboy y listo ya lo tendran para usarlo, claro si instalaron de cero como yo necesitara bajar unos 26 mb, librerias y demas.
ahora ando busando uno para xp y poder sincronizar los dos, recontra util tomar notas!! quien no ha pasado que esta en su pc pensando algo y viene un """"%%%%%"" o llaman por fono o hay temblo o que se yo. y tus ideas donde quedan? entonces tomboy un simple papel de notas como le digo yo pero en pc, asi que si uds pasan eso y necesitan anotar eso y lo mejor con buscador y todo pues usen tomboy.
si encuentran para xp avisen y si sincroniza con tomboy mejor :)
claro usando gnome, ahora si usan kde les queda solo knotes, pero a mi me gusta mas tomboy!
http://www.gnome.org/projects/tomboy/
knotes
Easy & secure remote access from anywhere
PCHelpWare is a free alternative to the various paying remote assistance services that can be found on the net
PCHelpWare is a powerfull remote support software that allows you to control (right from your own PC) a distant PC connected to the internet. It is the ideal solution to provide quick remote assistance and help your customers, collegues, friends and family members, even if they are on the other side of the world
PCHelpWare is customizable: you can create your own server package with your logo and -company- name
The individual you want to remotely assist only has to download and execute your customized package. That's all
No router/modem/firewall configuration is needed to access a remote PC even when it's standing on a protected network behind a NAT
If your PC is also behind Firewall/NAT routers, PCHelpware has the solution that makes everything simple anyway
Using the provided Repeater service, no router configuration is needed at all
http://www.uvnc.com/pchelpware/index.html
si quieren usar FOXPRO o DBASE, es decir sus tablas o bases de datos desde unix usando php, pues esta es su solucion vayan a la pagina incluso hay ejemplos. ma facil no puede ser.
ADOdb is a database abstraction library for PHP. There is also a Python version; see the ADOdb for Python docs.
The PHP version currently supports an amazing number of databases, thanks to the wonderful ADOdb community: MySQL, PostgreSQL, Interbase, Firebird, Informix, Oracle, MS SQL, Foxpro, Access, ADO, Sybase, FrontBase, DB2, SAP DB, SQLite, Netezza, LDAP, and generic ODBC, ODBTP. The Sybase, Informix, FrontBase and PostgreSQL, Netezza, LDAP, ODBTP drivers are community contributions. Here is the complete list of drivers.
Many popular web applications such as ACID, PostNuke, Xaraya, phpWiki, Mambo, PHP GACL, TikiWiki, eGroupWare and phpLens App Server are using ADOdb as their database abstraction layer. Some reasons why ADOdb is popular include:
- Designed for speed. It is probably the fastest open source database abstraction library available for PHP. See benchmarks.
- Provides extensive portability support such as date and type-handling and portable schema creation. See portable sql tips
- Support many enterprise features such as database backed sessions (with session expiry notification), SQL code generation, pivot tables, SELECT LIMIT emulation for all databases, performance monitoring.
- Easy to learn, especially if you have Window's programming experience, as it uses many ADO conventions.
- Extensive QA, every release is unit-tested on Access, MySQL, PostgreSQL, MS SQL, Oracle 9.
- Mature, continiously developed since August 2000. Has a large community of users.
- Very reasonable licensing terms (BSD). This means that you can incorporate (and even compile) it into your software applications royalty-free without asking the author's permission, provided you include license.txt in your release. Also dual-licensed (Lesser GPL).
otro si:
http://www.php.net/manual/es/ref.dbase.php
Qmail, sin lugar a dudas es un verdadero mta, mucho mejor y mas manipulable, estos dias he estado viendo un pequeño conflicto que tiene la version 1.0.3.4 al menos la que uso. no me ha pasado especificamente, pero he visto lentitud al tratar de conectar con los rblsmtpd cuando estos no estan presentes o no responden.
asi que recomendaria o desactivar los relays o tener cuidado con las caidas del qmail-smtpd.
si por ahi detectan caidas de qmail, siempre primero los log's luego verificar esta opcion, capaz es problema de los rblsmtpd
Pero despues fenomenal qmail.
5 Reglas Basicas para el perfecto infiel
Regla número Uno: No involucrarse
Si tienes necesidad de sacar los pies del plato y todo está dispuesto, pues házlo, pero Una o Dos veces, con la misma chica... ya no vayas a más, con más de dos te expones al involucramiento, y el involucramiento trae consigo que te encariñes, que te acostumbres, o que te enamores... Una vez, máximo dos, y es algo implícito a este deporte, recuerda: por cada mujer buena, hay otra MEJOR! Y si de antemano vas con esa mentalidad, te vas a esmerar más en dejarla que en quedarte con ella.
Regla número Dos: Sé selectivo
Por supuesto que es básico, siempre en este deporte te puedes exponer a encontrarte con alguien que no esta bien en su aspecto mental, osea posesivas, celosas, ilusas, locas, desubicadas... etc. Ten cuidado, en verdad si te chocas con una que no está bien de la cabeza, la vas a pasar muy mal, por eso y siempre q sea posible, trata de conservar tu identidad o tu domicilio o tu telefono fijo en reserva, el celu, lo puedes cambiar, eso es facil... pero ten todo eso chequeando antes de actuar.
Por supuesto, aún si has escogido bien, y terminas pues quedas como amigos "para lo q sea" y todo eso. Recuerda no hay nada peor que una mujer despechada, puede ser un enemigo mortal... así que pórtate bonito siempre. Caballero nomás...
Regla número Tres: Este secreto q tienes conmigo nadie lo sabrá
Esto parece ya absurdo mencionarlo, pero cofrádes, lo peor que pueden hacer es exponerse al pùblico, y aunque no lo crean algunos lo hacen cuando ya se creen unos MAESTROS, es lo peor que puede pasar... No se crean maestros, con esto se pierde el sentido de lo ALERTA, se confía uno, se deja estar... Recuerden siempre alerta, puedes tener un compañero de trampas, que te haga de escudero, pero no más, esto no es para vanagloriarse.
Las mujeres nunca te van a perdonar una infidelidad, asi que por favor no cometas el error de, al verte acorralado, confesarlo... no pes man! porque será porque te quiere, te ama o por lo que quieras y atraca volver: siempre ante la más mínima discusión o sospecha, tendrás que lidiar con este reproche, ellas por supuesto nunca olvidan, y tú, como te defiendes de la verdad?
Nunca lo admitas, ellas en el fondo, tambien quieres creer que es mentira. Asi tenga fotos, videos, te haya visto. Sé caradura: No eres tú el de la foto, es un montaje, te has equivocado, no es lo que tu piensas. Lo único relamente irremediable sería que te encuentre en la cama.
Regla número cinco: Primum non nocere
Si cumples con lo anterior, todo va a ir bien, sino, vas a hacer daño, si las cosas se salen de las manos, recuerda este principio (primero no hacer daño)... Imagina todo lo q te expones: tu tranquilidad !!!
En esto es básico que le digas a la trampa "eres trampa" y que ella acepte su condición, no le florees haciéndole pensar que vas a casarte con ella o que eres su príncipe azul, JAMAS, la matarás cuando la dejes y eso ella JAMAS te lo perdonará.
Y si no eres capaz de dominar tus emociones, no empieces este juego, no estas preparado para eso, y lo que mal empieza mal acaba. Aunque la practica ayuda bastante no siempre es definitiva cuando NO HAY dominio de las emociones.
Espero sea de utilidad, y también que se enriquezca con sus aportes, estimados cofrades, gracias a Dios hasta ahora voy bien...
Que puedo decir!! solo es lectura! :) :)
link

si esta interesado en comprar telefonos ip's aqui un estudio basado en ciertas caracteristicas que en la imagen misma salen.
link
Buscar cadenas de texto en GNU/Linux Si bien no existe un comando directo en linux para buscar cadenas, se puede hacer mediante la conjunción de tres comandos, poniendo en el intérprete de comandos la siguiente instrucción: ejm. find /home/ -type f | xargs grep "porno"
find "ruta" -type f | xargs grep "cadena a buscar"
Con find (y la opción usada) se buscan archivos en el directorio especificado (usar . para el directorio actual), el comando xargs combina cada elemento con el comando especificado y grep busca patrones en el archivo.
bueno entren aqui y bajense un software que les ayudara relativamente a saber si puedes o no usar win vista
interesante y huff ya no se puede pedir mas para empezar ah usar debian!
http://lists.debian.org/debian-boot/2007/01/msg01083.html
http://goodbye-microsoft.com/
http://goodbye-microsoft.com/screenshots/
inspirados en el proyecto ubuntu desde windows, ahora tenemos debian installer desde windows bajando un archivito de 500kb podemos iniciar la instalacion de DEBIAN (todos los caminos conducen a debian lol) .
aqui otro link de ubuntu desde windows
http://www.vivalinux.com.ar/distros/ubuntu-windows-install.html
cuando uno instala debian etch defrente para instalar firefox habran visto que ya no hay solo queda iceweasel, bueno para definir y entender un poco aquí un breve resumen
"IceWeasel" es el nombre de dos proyectos independientes de renombrado (designación) de Mozilla Firefox. Uno es parte de Gnuzilla, un proyecto GNU para suministrar versiones de programas de Mozilla constituidos, en su totalidad, de software libre. El otro es una compilación renombrada, preparada por Debian, para resolver la demanda hecha por Mozilla que les obligaba a dejar de utilizar el nombre o acojerse a sus términos, los cuales son inaceptables dentro de las políticas de Debian
Debian IceWeasel está basado en una versión modificada de Firefox, pero se le han quitado la mayoría de las marcas de Firefox. Es improbable que le sean aplicados más cambios a Iceweasel hasta después del lanzamiento de Debian Etch. ThunderBird y SeaMonkey se renombraron a IceDove y IceApe respectivamente, de la misma forma y por la misma razón.
La versión actual de Gnuzilla IceWeasel está basada en la versión 1.5.0.7 de Mozilla Firefox, mientras que la versión actual de Debian IceWeasel lo está en la 2.0.
respectivamente fuente
Para configurar el vencimiento de la contraseña para un usuario desde el intérprete de comandos, use el comando chage, seguido de una opción, seguido por el 'nombredeusuario' del usuario.
La contraseña oculta debe estar activada para poder usar el comando chage.
| Opción | Descripción |
|---|---|
| -m días | Especifica el número mínimo de días entre los cuales el usuario debe cambiar su contraseña. Si el valor es 0, la contraseña no caduca. |
| -M días | Especifica el número máximo de días durante los cuales la contraseña es válida. Cuando el número de días especificado por esta opción más el número de días especificado con la opción -d es menor que el día actual, el usuario debe cambiar su contraseña antes de usar la cuenta. |
| -d días | Especifica el número de días desde Enero 1, 1970 que la contraseña fué cambiada. |
| -I días | Especifica el número de días inactivos después de la expiración de la contraseña antes de bloquear la cuenta. Si el valor es 0, la cuenta no es bloqueada después que la contraseña caduca. |
| -E fecha | Especifica la fecha en la cual la cuenta es bloqueada, en el formato YYYY-MM-DD. También se puede usar el número de días transcurridos desde Enero 1, 1970 en lugar de la fecha. |
| -W días | Especifica el número de días antes de la fecha de expiración de la contraseña para advertir al usuario. |
Opciones de línea de comando : chage
Si el comando chage está seguido directamente por un nombre de usuario (sin opciones), se visualizará los valores de vencimiento de la contraseña actual y le permite cambiar estos valores.
Si el administrador del sistema desea que un usuario configure su contraseña la primera vez que éste se conecte, la contraseña del usuario puede ser configurada a que expire de inmediato, obligando al usuario a cambiarla inmediatamente después de conectarse la primera vez.
Para obligar al usuario a configurar su contraseña la primera vez que se conecte en la consola, siga los pasos siguientes. Este proceso no funciona si el usuario se conecta usando el protocolo SSH.
Bloquear la contraseña del usuario — Si el usuario no existe, use el comando useradd para crear la cuenta del usuario, pero no le de la contraseña para que así permanezca bloqueada.
Si la contraseña ya está activa, bloquéela con el comando:
usermod -L nombredeusuario
Obligar el vencimiento inmediato de la contraseña — Escriba el comando siguiente:
chage -d 0 nombredeusuario
Este comando coloca el valor para la fecha en que la contraseña fué cambiada la última vez (Enero 1, 1970). Este valor obliga a la expiración inmediata de la contraseña sin tomar en cuenta la política de vencimiento, si existe alguna.
FUENTE
gente, como olvidar este momento, por motivos x tuve que bajar fotos de una camera de 6megapixel hp photosmart una de las ultimitas.. casi nunca uso x, asi que era necesario bajar unas fotos de ahi. y que creen
debian etch, solo apt-get install xserver-xorg core gnome gnome-core y fonts. solo eso claro kernel 2.6.1x.x
el w2k necesitaba drivers y muchas cosas mas.. y encima no levantaba la camera.
linux debian etch, conecto el usb y listo lo puso como drive. y a copiar. que bacan. bueno me gusto ver la cara del compañero de microsoft. bueno no uso mucho X asi que me sorprendio a mi mismo como tan sencillo es en XORG ahora antes era mucho mas dificil.
ah usar debian etch señores, mas no se puede pedir. un apt-get instal abiword y listo no necesito nada mas.
IMHO.
bueno solo para indicar sobre este problemilla, cuando uno instala etch desde un net install no probe el completo (mucho ocio) y al fina terminas usando algun repositorio para meter tus paquetes, pues encontraras este problemita de LLAVES PUBLICAS
W: GPG error: http://www.debian-multimedia.org etch Release: Las firmas siguientes no se pudieron verificar porque su llave pública no está disponible: NO_PUBKEY 075G78785GHB907
bien esto se soluciona siguiendo este tutorial :
apt-get y el error NO_PUBKEY
Creación: 26-04-2006
Índice de contenidos
1. Introducción
Los que, como yo, usáis Debian GNU/Linux, seguramente estaréis encantados con su sistema de gestión de paquetes (para mi lo mejorcito que he visto y usado).
De vez en cuando usaréis apt-get (o synaptic, o kpackage, o cualquier otra herramienta basada en apt-get) para actualizar de forma automática vuestro sistema.
Es posible que al hacer apt-get update os aparezca un mensaje de alerta del estilo:
W: GPG error: http://ftp.debian.org unstable Release: Las firmas siguientes no se pudieron verificar porque su llave pública no está disponible: NO_PUBKEY 010908312D230C5F
Este mensaje se debe a que los paquetes del repositorio están firmados mediantes certificado digital, y las claves públicas para poder leer estos certificados están desactualizadas en vuestro repositorio de paquetes. Esto quiere decir que vuestro sistema puede actualizarse, pero no está seguro de quien le está proporcionando los paquetes.
En este tutorial vamos a ver una sencilla manera para actualizar las claves públicas de nuestro repositorio de paquetes.
2. Entorno
El tutorial está escrito usando el siguiente entorno:
Hardware: Portátil Ahtec Signal 259M MXM (Sonoma 2.1 GHz, 2048 MB RAM, 100 GB HD).
Sistema Operativo: GNU / Linux, Debian Sid (unstable), Kernel 2.6.16, KDE 3.5
3. Como actualizar las claves públicas del repositorio de paquetes
Primero nos tenemos que descargar las claves públicas. Para ello ejecutamos:
# gpg --keyserver keyring.debian.org --recv-key 2D230C5F
Donde 2D230C5F son los últimos 8 caracteres del mensaje de alerta que aparece al hacer apt-get update.
Una vez descargada la clave pública, basta con añadirla a nuestro repositorio de paquetes ejecutando el comando:
# gpg --armor --export 2D230C5F | apt-key add -
Para ver la lista de claves que hay en nuestro repositorio de paquetes podemos hacer:
# apt-key list
y obtendremos algo como:
/etc/apt/trusted.gpg
--------------------
pub 1024D/2D230C5F 2006-01-03 [caduca: 2007-02-07]
uid Debian Archive Automatic Signing Key (2006)
Si ahora volvemos a ejecutar apt-get update ya no nos aparecerá ningún mensaje de alerta.
Fuente:
http://www.adictosaltrabajo.com/tutoriales/tutoriales.php?pagina=debianAptNoPubKey
Bueno finalmente ya esta el rc3 de firefox 2.0 y esta muy bueno se ha integrado el cerrar cada pestaña de forma individual, esta un poco mas rapido! y sus botones ligeramente mas suavizados!!
puedes arrastrar las pestañas para cambiar el orden de aparición, se cierra y abre ligeramente mas rapido bueno mucho mas rapido el ctrl-t es mas efectivo..
pero bueno pruebenlo bajandolo de aqui:
http://releases.mozilla.org/pub/mozilla.org/firefox/releases/2.0/
para Linux
y para winXXX
siempre suele ocurrir que aparecen nuevas extensiones, o algún cliente dice me mandaron un archivo como lo abro.. y bueno hay que buscar y todo eso... pues esta pagina muy buena te facilita las cosas solo pon la extension y listo te dira todo lo referente ah ella.
hasta ahora no ha fallado siempre encuentra.
espero os sirva :
http://filext.com/

